# Arlunio  ![MIT License](https://img.shields.io/github/license/alcarney/arlunio.svg)  [![Gitter](https://badges.gitter.im/arlunio-py/Lobby.svg)](https://gitter.im/arlunio-py/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
|   | **Stable** | **Snapshot** |
|:-------------:|----|----|
| **Docs** | [![Documentation Status](https://readthedocs.org/projects/arlunio/badge/?version=stable)](https://arlunio.readthedocs.io/en/stable/?badge=stable) | [![Documentation Status](https://readthedocs.org/projects/arlunio/badge/?version=latest)](https://arlunio.readthedocs.io/en/latest/?badge=latest)|
| **Code**  [![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black) | [![Build Status](https://dev.azure.com/alcarney/Swyddfa/_apis/build/status/swyddfa.arlunio.python?branchName=master)](https://dev.azure.com/alcarney/Swyddfa/_build/latest?definitionId=2&branchName=master) | [![Build Status](https://dev.azure.com/alcarney/Swyddfa/_apis/build/status/swyddfa.arlunio?branchName=develop)](https://dev.azure.com/alcarney/Swyddfa/_build/latest?definitionId=1&branchName=develop)[![codecov](https://codecov.io/gh/swyddfa/arlunio/branch/develop/graph/badge.svg)](https://codecov.io/gh/swyddfa/arlunio)|
| **PyPi** | [![PyPi Version](https://img.shields.io/pypi/v/arlunio.svg)](https://pypi.org/project/arlunio) [![PyPi Supported Versions](https://img.shields.io/pypi/pyversions/arlunio.svg)](https://pypi.org/project/arlunio)|
| **Snap** | | [![arlunio](https://snapcraft.io/arlunio/badge.svg)](https://snapcraft.io/arlunio) |

**Arlunio is in early development, while it is useable we cannot make any
stability guarantees.**

Arlunio is a Python library that allows you to create images and animations
powered by your imagination and a little mathematics. While mathematics is very
much at the core you do not have to be a mathematician to use it!


```python
import arlunio as st

# Example coming soon!
```

## Installation

Arlunio is available for Python 3.6+ and can be installed using Pip:

```sh
$ pip install arlunio
```

Be sure to check out the [documentation](https://arlunio.readthedocs.io/en/latest/)
(under construction) for details on how to get started with arlunio.

## Contributing

Contributions are welcome! Just bear with us while contribution guidelines are
written up
